# -*- coding: utf-8 -*-
#
# TARGET arch is: ['--include', 'stdint.h', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '--include', 'linux/drivers/gpu/drm/amd/include/atom-types.h', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '--include', 'linux/drivers/gpu/drm/amd/include/atomfirmware.h', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '--include', 'linux/drivers/gpu/drm/amd/pm/inc/smu11_driver_if.h', '']
# WORD_SIZE is: 8
# POINTER_SIZE is: 8
# LONGDOUBLE_SIZE is: 16
#
import ctypes




class struct_atom_common_table_header(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('structuresize', ctypes.c_uint16),
    ('format_revision', ctypes.c_ubyte),
    ('content_revision', ctypes.c_ubyte),
     ]

class struct_c__SA_I2cControllerConfig_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('Enabled', ctypes.c_uint32),
    ('SlaveAddress', ctypes.c_uint32),
    ('ControllerPort', ctypes.c_uint32),
    ('ControllerName', ctypes.c_uint32),
    ('ThermalThrottler', ctypes.c_uint32),
    ('I2cProtocol', ctypes.c_uint32),
    ('I2cSpeed', ctypes.c_uint32),
     ]

class struct_c__SA_QuadraticInt_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('a', ctypes.c_uint32),
    ('b', ctypes.c_uint32),
    ('c', ctypes.c_uint32),
     ]

class struct_c__SA_LinearInt_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('m', ctypes.c_uint32),
    ('b', ctypes.c_uint32),
     ]

class struct_c__SA_DroopInt_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('a', ctypes.c_uint32),
    ('b', ctypes.c_uint32),
    ('c', ctypes.c_uint32),
     ]

class struct_c__SA_DpmDescriptor_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('VoltageMode', ctypes.c_ubyte),
    ('SnapToDiscrete', ctypes.c_ubyte),
    ('NumDiscreteLevels', ctypes.c_ubyte),
    ('padding', ctypes.c_ubyte),
    ('ConversionToAvfsClk', struct_c__SA_LinearInt_t),
    ('SsCurve', struct_c__SA_QuadraticInt_t),
     ]

class struct_c__SA_PPTable_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('Version', ctypes.c_uint32),
    ('FeaturesToRun', ctypes.c_uint32 * 2),
    ('SocketPowerLimitAc0', ctypes.c_uint16),
    ('SocketPowerLimitAc0Tau', ctypes.c_uint16),
    ('SocketPowerLimitAc1', ctypes.c_uint16),
    ('SocketPowerLimitAc1Tau', ctypes.c_uint16),
    ('SocketPowerLimitAc2', ctypes.c_uint16),
    ('SocketPowerLimitAc2Tau', ctypes.c_uint16),
    ('SocketPowerLimitAc3', ctypes.c_uint16),
    ('SocketPowerLimitAc3Tau', ctypes.c_uint16),
    ('SocketPowerLimitDc', ctypes.c_uint16),
    ('SocketPowerLimitDcTau', ctypes.c_uint16),
    ('TdcLimitSoc', ctypes.c_uint16),
    ('TdcLimitSocTau', ctypes.c_uint16),
    ('TdcLimitGfx', ctypes.c_uint16),
    ('TdcLimitGfxTau', ctypes.c_uint16),
    ('TedgeLimit', ctypes.c_uint16),
    ('ThotspotLimit', ctypes.c_uint16),
    ('ThbmLimit', ctypes.c_uint16),
    ('Tvr_gfxLimit', ctypes.c_uint16),
    ('Tvr_memLimit', ctypes.c_uint16),
    ('Tliquid1Limit', ctypes.c_uint16),
    ('Tliquid2Limit', ctypes.c_uint16),
    ('TplxLimit', ctypes.c_uint16),
    ('FitLimit', ctypes.c_uint32),
    ('PpmPowerLimit', ctypes.c_uint16),
    ('PpmTemperatureThreshold', ctypes.c_uint16),
    ('MemoryOnPackage', ctypes.c_ubyte),
    ('padding8_limits', ctypes.c_ubyte),
    ('Tvr_SocLimit', ctypes.c_uint16),
    ('UlvVoltageOffsetSoc', ctypes.c_uint16),
    ('UlvVoltageOffsetGfx', ctypes.c_uint16),
    ('UlvSmnclkDid', ctypes.c_ubyte),
    ('UlvMp1clkDid', ctypes.c_ubyte),
    ('UlvGfxclkBypass', ctypes.c_ubyte),
    ('Padding234', ctypes.c_ubyte),
    ('MinVoltageGfx', ctypes.c_uint16),
    ('MinVoltageSoc', ctypes.c_uint16),
    ('MaxVoltageGfx', ctypes.c_uint16),
    ('MaxVoltageSoc', ctypes.c_uint16),
    ('LoadLineResistanceGfx', ctypes.c_uint16),
    ('LoadLineResistanceSoc', ctypes.c_uint16),
    ('DpmDescriptor', struct_c__SA_DpmDescriptor_t * 11),
    ('FreqTableGfx', ctypes.c_uint16 * 16),
    ('FreqTableVclk', ctypes.c_uint16 * 8),
    ('FreqTableDclk', ctypes.c_uint16 * 8),
    ('FreqTableEclk', ctypes.c_uint16 * 8),
    ('FreqTableSocclk', ctypes.c_uint16 * 8),
    ('FreqTableUclk', ctypes.c_uint16 * 4),
    ('FreqTableFclk', ctypes.c_uint16 * 8),
    ('FreqTableDcefclk', ctypes.c_uint16 * 8),
    ('FreqTableDispclk', ctypes.c_uint16 * 8),
    ('FreqTablePixclk', ctypes.c_uint16 * 8),
    ('FreqTablePhyclk', ctypes.c_uint16 * 8),
    ('DcModeMaxFreq', ctypes.c_uint16 * 11),
    ('Padding8_Clks', ctypes.c_uint16),
    ('Mp0clkFreq', ctypes.c_uint16 * 2),
    ('Mp0DpmVoltage', ctypes.c_uint16 * 2),
    ('GfxclkFidle', ctypes.c_uint16),
    ('GfxclkSlewRate', ctypes.c_uint16),
    ('CksEnableFreq', ctypes.c_uint16),
    ('Padding789', ctypes.c_uint16),
    ('CksVoltageOffset', struct_c__SA_QuadraticInt_t),
    ('Padding567', ctypes.c_ubyte * 4),
    ('GfxclkDsMaxFreq', ctypes.c_uint16),
    ('GfxclkSource', ctypes.c_ubyte),
    ('Padding456', ctypes.c_ubyte),
    ('LowestUclkReservedForUlv', ctypes.c_ubyte),
    ('Padding8_Uclk', ctypes.c_ubyte * 3),
    ('PcieGenSpeed', ctypes.c_ubyte * 2),
    ('PcieLaneCount', ctypes.c_ubyte * 2),
    ('LclkFreq', ctypes.c_uint16 * 2),
    ('EnableTdpm', ctypes.c_uint16),
    ('TdpmHighHystTemperature', ctypes.c_uint16),
    ('TdpmLowHystTemperature', ctypes.c_uint16),
    ('GfxclkFreqHighTempLimit', ctypes.c_uint16),
    ('FanStopTemp', ctypes.c_uint16),
    ('FanStartTemp', ctypes.c_uint16),
    ('FanGainEdge', ctypes.c_uint16),
    ('FanGainHotspot', ctypes.c_uint16),
    ('FanGainLiquid', ctypes.c_uint16),
    ('FanGainVrGfx', ctypes.c_uint16),
    ('FanGainVrSoc', ctypes.c_uint16),
    ('FanGainPlx', ctypes.c_uint16),
    ('FanGainHbm', ctypes.c_uint16),
    ('FanPwmMin', ctypes.c_uint16),
    ('FanAcousticLimitRpm', ctypes.c_uint16),
    ('FanThrottlingRpm', ctypes.c_uint16),
    ('FanMaximumRpm', ctypes.c_uint16),
    ('FanTargetTemperature', ctypes.c_uint16),
    ('FanTargetGfxclk', ctypes.c_uint16),
    ('FanZeroRpmEnable', ctypes.c_ubyte),
    ('FanTachEdgePerRev', ctypes.c_ubyte),
    ('FuzzyFan_ErrorSetDelta', ctypes.c_int16),
    ('FuzzyFan_ErrorRateSetDelta', ctypes.c_int16),
    ('FuzzyFan_PwmSetDelta', ctypes.c_int16),
    ('FuzzyFan_Reserved', ctypes.c_uint16),
    ('OverrideAvfsGb', ctypes.c_ubyte * 2),
    ('Padding8_Avfs', ctypes.c_ubyte * 2),
    ('qAvfsGb', struct_c__SA_QuadraticInt_t * 2),
    ('dBtcGbGfxCksOn', struct_c__SA_DroopInt_t),
    ('dBtcGbGfxCksOff', struct_c__SA_DroopInt_t),
    ('dBtcGbGfxAfll', struct_c__SA_DroopInt_t),
    ('dBtcGbSoc', struct_c__SA_DroopInt_t),
    ('qAgingGb', struct_c__SA_LinearInt_t * 2),
    ('qStaticVoltageOffset', struct_c__SA_QuadraticInt_t * 2),
    ('DcTol', ctypes.c_uint16 * 2),
    ('DcBtcEnabled', ctypes.c_ubyte * 2),
    ('Padding8_GfxBtc', ctypes.c_ubyte * 2),
    ('DcBtcMin', ctypes.c_int16 * 2),
    ('DcBtcMax', ctypes.c_uint16 * 2),
    ('XgmiLinkSpeed', ctypes.c_ubyte * 2),
    ('XgmiLinkWidth', ctypes.c_ubyte * 2),
    ('XgmiFclkFreq', ctypes.c_uint16 * 2),
    ('XgmiUclkFreq', ctypes.c_uint16 * 2),
    ('XgmiSocclkFreq', ctypes.c_uint16 * 2),
    ('XgmiSocVoltage', ctypes.c_uint16 * 2),
    ('DebugOverrides', ctypes.c_uint32),
    ('ReservedEquation0', struct_c__SA_QuadraticInt_t),
    ('ReservedEquation1', struct_c__SA_QuadraticInt_t),
    ('ReservedEquation2', struct_c__SA_QuadraticInt_t),
    ('ReservedEquation3', struct_c__SA_QuadraticInt_t),
    ('MinVoltageUlvGfx', ctypes.c_uint16),
    ('MinVoltageUlvSoc', ctypes.c_uint16),
    ('MGpuFanBoostLimitRpm', ctypes.c_uint16),
    ('padding16_Fan', ctypes.c_uint16),
    ('FanGainVrMem0', ctypes.c_uint16),
    ('FanGainVrMem1', ctypes.c_uint16),
    ('DcBtcGb', ctypes.c_uint16 * 2),
    ('Reserved', ctypes.c_uint32 * 11),
    ('Padding32', ctypes.c_uint32 * 3),
    ('MaxVoltageStepGfx', ctypes.c_uint16),
    ('MaxVoltageStepSoc', ctypes.c_uint16),
    ('VddGfxVrMapping', ctypes.c_ubyte),
    ('VddSocVrMapping', ctypes.c_ubyte),
    ('VddMem0VrMapping', ctypes.c_ubyte),
    ('VddMem1VrMapping', ctypes.c_ubyte),
    ('GfxUlvPhaseSheddingMask', ctypes.c_ubyte),
    ('SocUlvPhaseSheddingMask', ctypes.c_ubyte),
    ('ExternalSensorPresent', ctypes.c_ubyte),
    ('Padding8_V', ctypes.c_ubyte),
    ('GfxMaxCurrent', ctypes.c_uint16),
    ('GfxOffset', ctypes.c_byte),
    ('Padding_TelemetryGfx', ctypes.c_ubyte),
    ('SocMaxCurrent', ctypes.c_uint16),
    ('SocOffset', ctypes.c_byte),
    ('Padding_TelemetrySoc', ctypes.c_ubyte),
    ('Mem0MaxCurrent', ctypes.c_uint16),
    ('Mem0Offset', ctypes.c_byte),
    ('Padding_TelemetryMem0', ctypes.c_ubyte),
    ('Mem1MaxCurrent', ctypes.c_uint16),
    ('Mem1Offset', ctypes.c_byte),
    ('Padding_TelemetryMem1', ctypes.c_ubyte),
    ('AcDcGpio', ctypes.c_ubyte),
    ('AcDcPolarity', ctypes.c_ubyte),
    ('VR0HotGpio', ctypes.c_ubyte),
    ('VR0HotPolarity', ctypes.c_ubyte),
    ('VR1HotGpio', ctypes.c_ubyte),
    ('VR1HotPolarity', ctypes.c_ubyte),
    ('Padding1', ctypes.c_ubyte),
    ('Padding2', ctypes.c_ubyte),
    ('LedPin0', ctypes.c_ubyte),
    ('LedPin1', ctypes.c_ubyte),
    ('LedPin2', ctypes.c_ubyte),
    ('padding8_4', ctypes.c_ubyte),
    ('PllGfxclkSpreadEnabled', ctypes.c_ubyte),
    ('PllGfxclkSpreadPercent', ctypes.c_ubyte),
    ('PllGfxclkSpreadFreq', ctypes.c_uint16),
    ('UclkSpreadEnabled', ctypes.c_ubyte),
    ('UclkSpreadPercent', ctypes.c_ubyte),
    ('UclkSpreadFreq', ctypes.c_uint16),
    ('FclkSpreadEnabled', ctypes.c_ubyte),
    ('FclkSpreadPercent', ctypes.c_ubyte),
    ('FclkSpreadFreq', ctypes.c_uint16),
    ('FllGfxclkSpreadEnabled', ctypes.c_ubyte),
    ('FllGfxclkSpreadPercent', ctypes.c_ubyte),
    ('FllGfxclkSpreadFreq', ctypes.c_uint16),
    ('I2cControllers', struct_c__SA_I2cControllerConfig_t * 7),
    ('BoardReserved', ctypes.c_uint32 * 10),
    ('MmHubPadding', ctypes.c_uint32 * 8),
     ]

_VEGA20_PPTABLE_H_ = True # macro
ATOM_VEGA20_PP_THERMALCONTROLLER_NONE = 0 # macro
ATOM_VEGA20_PP_THERMALCONTROLLER_VEGA20 = 26 # macro
ATOM_VEGA20_PP_PLATFORM_CAP_POWERPLAY = 0x1 # macro
ATOM_VEGA20_PP_PLATFORM_CAP_SBIOSPOWERSOURCE = 0x2 # macro
ATOM_VEGA20_PP_PLATFORM_CAP_HARDWAREDC = 0x4 # macro
ATOM_VEGA20_PP_PLATFORM_CAP_BACO = 0x8 # macro
ATOM_VEGA20_PP_PLATFORM_CAP_BAMACO = 0x10 # macro
ATOM_VEGA20_PP_PLATFORM_CAP_ENABLESHADOWPSTATE = 0x20 # macro
ATOM_VEGA20_TABLE_REVISION_VEGA20 = 11 # macro
ATOM_VEGA20_ODFEATURE_MAX_COUNT = 32 # macro
ATOM_VEGA20_ODSETTING_MAX_COUNT = 32 # macro
ATOM_VEGA20_PPCLOCK_MAX_COUNT = 16 # macro
class struct__ATOM_VEGA20_OVERDRIVE8_RECORD(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('ucODTableRevision', ctypes.c_ubyte),
    ('ODFeatureCount', ctypes.c_uint32),
    ('ODFeatureCapabilities', ctypes.c_ubyte * 32),
    ('ODSettingCount', ctypes.c_uint32),
    ('ODSettingsMax', ctypes.c_uint32 * 32),
    ('ODSettingsMin', ctypes.c_uint32 * 32),
     ]

ATOM_VEGA20_OVERDRIVE8_RECORD = struct__ATOM_VEGA20_OVERDRIVE8_RECORD
class struct__ATOM_VEGA20_POWER_SAVING_CLOCK_RECORD(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('ucTableRevision', ctypes.c_ubyte),
    ('PowerSavingClockCount', ctypes.c_uint32),
    ('PowerSavingClockMax', ctypes.c_uint32 * 16),
    ('PowerSavingClockMin', ctypes.c_uint32 * 16),
     ]

ATOM_VEGA20_POWER_SAVING_CLOCK_RECORD = struct__ATOM_VEGA20_POWER_SAVING_CLOCK_RECORD
class struct__ATOM_VEGA20_POWERPLAYTABLE(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('sHeader', struct_atom_common_table_header),
    ('ucTableRevision', ctypes.c_ubyte),
    ('usTableSize', ctypes.c_uint16),
    ('ulGoldenPPID', ctypes.c_uint32),
    ('ulGoldenRevision', ctypes.c_uint32),
    ('usFormatID', ctypes.c_uint16),
    ('ulPlatformCaps', ctypes.c_uint32),
    ('ucThermalControllerType', ctypes.c_ubyte),
    ('usSmallPowerLimit1', ctypes.c_uint16),
    ('usSmallPowerLimit2', ctypes.c_uint16),
    ('usBoostPowerLimit', ctypes.c_uint16),
    ('usODTurboPowerLimit', ctypes.c_uint16),
    ('usODPowerSavePowerLimit', ctypes.c_uint16),
    ('usSoftwareShutdownTemp', ctypes.c_uint16),
    ('PowerSavingClockTable', ATOM_VEGA20_POWER_SAVING_CLOCK_RECORD),
    ('OverDrive8Table', ATOM_VEGA20_OVERDRIVE8_RECORD),
    ('usReserve', ctypes.c_uint16 * 5),
    ('smcPPTable', struct_c__SA_PPTable_t),
     ]

ATOM_Vega20_POWERPLAYTABLE = struct__ATOM_VEGA20_POWERPLAYTABLE
__all__ = \
    ['ATOM_VEGA20_ODFEATURE_MAX_COUNT',
    'ATOM_VEGA20_ODSETTING_MAX_COUNT',
    'ATOM_VEGA20_OVERDRIVE8_RECORD',
    'ATOM_VEGA20_POWER_SAVING_CLOCK_RECORD',
    'ATOM_VEGA20_PPCLOCK_MAX_COUNT',
    'ATOM_VEGA20_PP_PLATFORM_CAP_BACO',
    'ATOM_VEGA20_PP_PLATFORM_CAP_BAMACO',
    'ATOM_VEGA20_PP_PLATFORM_CAP_ENABLESHADOWPSTATE',
    'ATOM_VEGA20_PP_PLATFORM_CAP_HARDWAREDC',
    'ATOM_VEGA20_PP_PLATFORM_CAP_POWERPLAY',
    'ATOM_VEGA20_PP_PLATFORM_CAP_SBIOSPOWERSOURCE',
    'ATOM_VEGA20_PP_THERMALCONTROLLER_NONE',
    'ATOM_VEGA20_PP_THERMALCONTROLLER_VEGA20',
    'ATOM_VEGA20_TABLE_REVISION_VEGA20', 'ATOM_Vega20_POWERPLAYTABLE',
    '_VEGA20_PPTABLE_H_', 'struct__ATOM_VEGA20_OVERDRIVE8_RECORD',
    'struct__ATOM_VEGA20_POWERPLAYTABLE',
    'struct__ATOM_VEGA20_POWER_SAVING_CLOCK_RECORD',
    'struct_atom_common_table_header', 'struct_c__SA_DpmDescriptor_t',
    'struct_c__SA_DroopInt_t', 'struct_c__SA_I2cControllerConfig_t',
    'struct_c__SA_LinearInt_t', 'struct_c__SA_PPTable_t',
    'struct_c__SA_QuadraticInt_t']



# -*- coding: utf-8 -*-
#
# TARGET arch is: ['--include', 'stdint.h', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '--include', 'linux/drivers/gpu/drm/amd/include/atom-types.h', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '--include', 'linux/drivers/gpu/drm/amd/include/atomfirmware.h', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '--include', 'linux/drivers/gpu/drm/amd/pm/inc/smu11_driver_if_navi10.h', '']
# WORD_SIZE is: 8
# POINTER_SIZE is: 8
# LONGDOUBLE_SIZE is: 16
#
import ctypes




class struct_atom_common_table_header(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('structuresize', ctypes.c_uint16),
    ('format_revision', ctypes.c_ubyte),
    ('content_revision', ctypes.c_ubyte),
     ]

class struct_c__SA_I2cControllerConfig_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('Enabled', ctypes.c_ubyte),
    ('Speed', ctypes.c_ubyte),
    ('Padding', ctypes.c_ubyte * 2),
    ('SlaveAddress', ctypes.c_uint32),
    ('ControllerPort', ctypes.c_ubyte),
    ('ControllerName', ctypes.c_ubyte),
    ('ThermalThrotter', ctypes.c_ubyte),
    ('I2cProtocol', ctypes.c_ubyte),
     ]

class struct_c__SA_QuadraticInt_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('a', ctypes.c_uint32),
    ('b', ctypes.c_uint32),
    ('c', ctypes.c_uint32),
     ]

class struct_c__SA_LinearInt_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('m', ctypes.c_uint32),
    ('b', ctypes.c_uint32),
     ]

class struct_c__SA_DroopInt_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('a', ctypes.c_uint32),
    ('b', ctypes.c_uint32),
    ('c', ctypes.c_uint32),
     ]

class struct_c__SA_DpmDescriptor_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('VoltageMode', ctypes.c_ubyte),
    ('SnapToDiscrete', ctypes.c_ubyte),
    ('NumDiscreteLevels', ctypes.c_ubyte),
    ('Padding', ctypes.c_ubyte),
    ('ConversionToAvfsClk', struct_c__SA_LinearInt_t),
    ('SsCurve', struct_c__SA_QuadraticInt_t),
     ]

class struct_c__SA_PPTable_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('Version', ctypes.c_uint32),
    ('FeaturesToRun', ctypes.c_uint32 * 2),
    ('SocketPowerLimitAc', ctypes.c_uint16 * 4),
    ('SocketPowerLimitAcTau', ctypes.c_uint16 * 4),
    ('SocketPowerLimitDc', ctypes.c_uint16 * 4),
    ('SocketPowerLimitDcTau', ctypes.c_uint16 * 4),
    ('TdcLimitSoc', ctypes.c_uint16),
    ('TdcLimitSocTau', ctypes.c_uint16),
    ('TdcLimitGfx', ctypes.c_uint16),
    ('TdcLimitGfxTau', ctypes.c_uint16),
    ('TedgeLimit', ctypes.c_uint16),
    ('ThotspotLimit', ctypes.c_uint16),
    ('TmemLimit', ctypes.c_uint16),
    ('Tvr_gfxLimit', ctypes.c_uint16),
    ('Tvr_mem0Limit', ctypes.c_uint16),
    ('Tvr_mem1Limit', ctypes.c_uint16),
    ('Tvr_socLimit', ctypes.c_uint16),
    ('Tliquid0Limit', ctypes.c_uint16),
    ('Tliquid1Limit', ctypes.c_uint16),
    ('TplxLimit', ctypes.c_uint16),
    ('FitLimit', ctypes.c_uint32),
    ('PpmPowerLimit', ctypes.c_uint16),
    ('PpmTemperatureThreshold', ctypes.c_uint16),
    ('ThrottlerControlMask', ctypes.c_uint32),
    ('FwDStateMask', ctypes.c_uint32),
    ('UlvVoltageOffsetSoc', ctypes.c_uint16),
    ('UlvVoltageOffsetGfx', ctypes.c_uint16),
    ('GceaLinkMgrIdleThreshold', ctypes.c_ubyte),
    ('paddingRlcUlvParams', ctypes.c_ubyte * 3),
    ('UlvSmnclkDid', ctypes.c_ubyte),
    ('UlvMp1clkDid', ctypes.c_ubyte),
    ('UlvGfxclkBypass', ctypes.c_ubyte),
    ('Padding234', ctypes.c_ubyte),
    ('MinVoltageUlvGfx', ctypes.c_uint16),
    ('MinVoltageUlvSoc', ctypes.c_uint16),
    ('MinVoltageGfx', ctypes.c_uint16),
    ('MinVoltageSoc', ctypes.c_uint16),
    ('MaxVoltageGfx', ctypes.c_uint16),
    ('MaxVoltageSoc', ctypes.c_uint16),
    ('LoadLineResistanceGfx', ctypes.c_uint16),
    ('LoadLineResistanceSoc', ctypes.c_uint16),
    ('DpmDescriptor', struct_c__SA_DpmDescriptor_t * 9),
    ('FreqTableGfx', ctypes.c_uint16 * 16),
    ('FreqTableVclk', ctypes.c_uint16 * 8),
    ('FreqTableDclk', ctypes.c_uint16 * 8),
    ('FreqTableSocclk', ctypes.c_uint16 * 8),
    ('FreqTableUclk', ctypes.c_uint16 * 4),
    ('FreqTableDcefclk', ctypes.c_uint16 * 8),
    ('FreqTableDispclk', ctypes.c_uint16 * 8),
    ('FreqTablePixclk', ctypes.c_uint16 * 8),
    ('FreqTablePhyclk', ctypes.c_uint16 * 8),
    ('Paddingclks', ctypes.c_uint32 * 16),
    ('DcModeMaxFreq', ctypes.c_uint16 * 9),
    ('Padding8_Clks', ctypes.c_uint16),
    ('FreqTableUclkDiv', ctypes.c_ubyte * 4),
    ('Mp0clkFreq', ctypes.c_uint16 * 2),
    ('Mp0DpmVoltage', ctypes.c_uint16 * 2),
    ('MemVddciVoltage', ctypes.c_uint16 * 4),
    ('MemMvddVoltage', ctypes.c_uint16 * 4),
    ('GfxclkFgfxoffEntry', ctypes.c_uint16),
    ('GfxclkFinit', ctypes.c_uint16),
    ('GfxclkFidle', ctypes.c_uint16),
    ('GfxclkSlewRate', ctypes.c_uint16),
    ('GfxclkFopt', ctypes.c_uint16),
    ('Padding567', ctypes.c_ubyte * 2),
    ('GfxclkDsMaxFreq', ctypes.c_uint16),
    ('GfxclkSource', ctypes.c_ubyte),
    ('Padding456', ctypes.c_ubyte),
    ('LowestUclkReservedForUlv', ctypes.c_ubyte),
    ('paddingUclk', ctypes.c_ubyte * 3),
    ('MemoryType', ctypes.c_ubyte),
    ('MemoryChannels', ctypes.c_ubyte),
    ('PaddingMem', ctypes.c_ubyte * 2),
    ('PcieGenSpeed', ctypes.c_ubyte * 2),
    ('PcieLaneCount', ctypes.c_ubyte * 2),
    ('LclkFreq', ctypes.c_uint16 * 2),
    ('EnableTdpm', ctypes.c_uint16),
    ('TdpmHighHystTemperature', ctypes.c_uint16),
    ('TdpmLowHystTemperature', ctypes.c_uint16),
    ('GfxclkFreqHighTempLimit', ctypes.c_uint16),
    ('FanStopTemp', ctypes.c_uint16),
    ('FanStartTemp', ctypes.c_uint16),
    ('FanGainEdge', ctypes.c_uint16),
    ('FanGainHotspot', ctypes.c_uint16),
    ('FanGainLiquid0', ctypes.c_uint16),
    ('FanGainLiquid1', ctypes.c_uint16),
    ('FanGainVrGfx', ctypes.c_uint16),
    ('FanGainVrSoc', ctypes.c_uint16),
    ('FanGainVrMem0', ctypes.c_uint16),
    ('FanGainVrMem1', ctypes.c_uint16),
    ('FanGainPlx', ctypes.c_uint16),
    ('FanGainMem', ctypes.c_uint16),
    ('FanPwmMin', ctypes.c_uint16),
    ('FanAcousticLimitRpm', ctypes.c_uint16),
    ('FanThrottlingRpm', ctypes.c_uint16),
    ('FanMaximumRpm', ctypes.c_uint16),
    ('FanTargetTemperature', ctypes.c_uint16),
    ('FanTargetGfxclk', ctypes.c_uint16),
    ('FanTempInputSelect', ctypes.c_ubyte),
    ('FanPadding', ctypes.c_ubyte),
    ('FanZeroRpmEnable', ctypes.c_ubyte),
    ('FanTachEdgePerRev', ctypes.c_ubyte),
    ('FuzzyFan_ErrorSetDelta', ctypes.c_int16),
    ('FuzzyFan_ErrorRateSetDelta', ctypes.c_int16),
    ('FuzzyFan_PwmSetDelta', ctypes.c_int16),
    ('FuzzyFan_Reserved', ctypes.c_uint16),
    ('OverrideAvfsGb', ctypes.c_ubyte * 2),
    ('Padding8_Avfs', ctypes.c_ubyte * 2),
    ('qAvfsGb', struct_c__SA_QuadraticInt_t * 2),
    ('dBtcGbGfxPll', struct_c__SA_DroopInt_t),
    ('dBtcGbGfxDfll', struct_c__SA_DroopInt_t),
    ('dBtcGbSoc', struct_c__SA_DroopInt_t),
    ('qAgingGb', struct_c__SA_LinearInt_t * 2),
    ('qStaticVoltageOffset', struct_c__SA_QuadraticInt_t * 2),
    ('DcTol', ctypes.c_uint16 * 2),
    ('DcBtcEnabled', ctypes.c_ubyte * 2),
    ('Padding8_GfxBtc', ctypes.c_ubyte * 2),
    ('DcBtcMin', ctypes.c_uint16 * 2),
    ('DcBtcMax', ctypes.c_uint16 * 2),
    ('DebugOverrides', ctypes.c_uint32),
    ('ReservedEquation0', struct_c__SA_QuadraticInt_t),
    ('ReservedEquation1', struct_c__SA_QuadraticInt_t),
    ('ReservedEquation2', struct_c__SA_QuadraticInt_t),
    ('ReservedEquation3', struct_c__SA_QuadraticInt_t),
    ('TotalPowerConfig', ctypes.c_ubyte),
    ('TotalPowerSpare1', ctypes.c_ubyte),
    ('TotalPowerSpare2', ctypes.c_uint16),
    ('PccThresholdLow', ctypes.c_uint16),
    ('PccThresholdHigh', ctypes.c_uint16),
    ('MGpuFanBoostLimitRpm', ctypes.c_uint32),
    ('PaddingAPCC', ctypes.c_uint32 * 5),
    ('VDDGFX_TVmin', ctypes.c_uint16),
    ('VDDSOC_TVmin', ctypes.c_uint16),
    ('VDDGFX_Vmin_HiTemp', ctypes.c_uint16),
    ('VDDGFX_Vmin_LoTemp', ctypes.c_uint16),
    ('VDDSOC_Vmin_HiTemp', ctypes.c_uint16),
    ('VDDSOC_Vmin_LoTemp', ctypes.c_uint16),
    ('VDDGFX_TVminHystersis', ctypes.c_uint16),
    ('VDDSOC_TVminHystersis', ctypes.c_uint16),
    ('BtcConfig', ctypes.c_uint32),
    ('SsFmin', ctypes.c_uint16 * 10),
    ('DcBtcGb', ctypes.c_uint16 * 2),
    ('Reserved', ctypes.c_uint32 * 8),
    ('I2cControllers', struct_c__SA_I2cControllerConfig_t * 8),
    ('MaxVoltageStepGfx', ctypes.c_uint16),
    ('MaxVoltageStepSoc', ctypes.c_uint16),
    ('VddGfxVrMapping', ctypes.c_ubyte),
    ('VddSocVrMapping', ctypes.c_ubyte),
    ('VddMem0VrMapping', ctypes.c_ubyte),
    ('VddMem1VrMapping', ctypes.c_ubyte),
    ('GfxUlvPhaseSheddingMask', ctypes.c_ubyte),
    ('SocUlvPhaseSheddingMask', ctypes.c_ubyte),
    ('ExternalSensorPresent', ctypes.c_ubyte),
    ('Padding8_V', ctypes.c_ubyte),
    ('GfxMaxCurrent', ctypes.c_uint16),
    ('GfxOffset', ctypes.c_byte),
    ('Padding_TelemetryGfx', ctypes.c_ubyte),
    ('SocMaxCurrent', ctypes.c_uint16),
    ('SocOffset', ctypes.c_byte),
    ('Padding_TelemetrySoc', ctypes.c_ubyte),
    ('Mem0MaxCurrent', ctypes.c_uint16),
    ('Mem0Offset', ctypes.c_byte),
    ('Padding_TelemetryMem0', ctypes.c_ubyte),
    ('Mem1MaxCurrent', ctypes.c_uint16),
    ('Mem1Offset', ctypes.c_byte),
    ('Padding_TelemetryMem1', ctypes.c_ubyte),
    ('AcDcGpio', ctypes.c_ubyte),
    ('AcDcPolarity', ctypes.c_ubyte),
    ('VR0HotGpio', ctypes.c_ubyte),
    ('VR0HotPolarity', ctypes.c_ubyte),
    ('VR1HotGpio', ctypes.c_ubyte),
    ('VR1HotPolarity', ctypes.c_ubyte),
    ('GthrGpio', ctypes.c_ubyte),
    ('GthrPolarity', ctypes.c_ubyte),
    ('LedPin0', ctypes.c_ubyte),
    ('LedPin1', ctypes.c_ubyte),
    ('LedPin2', ctypes.c_ubyte),
    ('padding8_4', ctypes.c_ubyte),
    ('PllGfxclkSpreadEnabled', ctypes.c_ubyte),
    ('PllGfxclkSpreadPercent', ctypes.c_ubyte),
    ('PllGfxclkSpreadFreq', ctypes.c_uint16),
    ('DfllGfxclkSpreadEnabled', ctypes.c_ubyte),
    ('DfllGfxclkSpreadPercent', ctypes.c_ubyte),
    ('DfllGfxclkSpreadFreq', ctypes.c_uint16),
    ('UclkSpreadEnabled', ctypes.c_ubyte),
    ('UclkSpreadPercent', ctypes.c_ubyte),
    ('UclkSpreadFreq', ctypes.c_uint16),
    ('SoclkSpreadEnabled', ctypes.c_ubyte),
    ('SocclkSpreadPercent', ctypes.c_ubyte),
    ('SocclkSpreadFreq', ctypes.c_uint16),
    ('TotalBoardPower', ctypes.c_uint16),
    ('BoardPadding', ctypes.c_uint16),
    ('MvddRatio', ctypes.c_uint32),
    ('RenesesLoadLineEnabled', ctypes.c_ubyte),
    ('GfxLoadlineResistance', ctypes.c_ubyte),
    ('SocLoadlineResistance', ctypes.c_ubyte),
    ('Padding8_Loadline', ctypes.c_ubyte),
    ('BoardReserved', ctypes.c_uint32 * 8),
    ('MmHubPadding', ctypes.c_uint32 * 8),
     ]

SMU_11_0_PPTABLE_H = True # macro
SMU_11_0_TABLE_FORMAT_REVISION = 12 # macro
SMU_11_0_PP_PLATFORM_CAP_POWERPLAY = 0x1 # macro
SMU_11_0_PP_PLATFORM_CAP_SBIOSPOWERSOURCE = 0x2 # macro
SMU_11_0_PP_PLATFORM_CAP_HARDWAREDC = 0x4 # macro
SMU_11_0_PP_PLATFORM_CAP_BACO = 0x8 # macro
SMU_11_0_PP_PLATFORM_CAP_MACO = 0x10 # macro
SMU_11_0_PP_PLATFORM_CAP_SHADOWPSTATE = 0x20 # macro
SMU_11_0_PP_THERMALCONTROLLER_NONE = 0 # macro
SMU_11_0_PP_OVERDRIVE_VERSION = 0x0800 # macro
SMU_11_0_PP_POWERSAVINGCLOCK_VERSION = 0x0100 # macro
SMU_11_0_MAX_ODFEATURE = 32 # macro
SMU_11_0_MAX_ODSETTING = 32 # macro
class struct_smu_11_0_overdrive_table(ctypes.Structure):
    _pack_ = True # source:True
    _fields_ = [
    ('revision', ctypes.c_ubyte),
    ('reserve', ctypes.c_ubyte * 3),
    ('feature_count', ctypes.c_uint32),
    ('setting_count', ctypes.c_uint32),
    ('cap', ctypes.c_ubyte * 32),
    ('max', ctypes.c_uint32 * 32),
    ('min', ctypes.c_uint32 * 32),
     ]

SMU_11_0_MAX_PPCLOCK = 16 # macro
class struct_smu_11_0_power_saving_clock_table(ctypes.Structure):
    _pack_ = True # source:True
    _fields_ = [
    ('revision', ctypes.c_ubyte),
    ('reserve', ctypes.c_ubyte * 3),
    ('count', ctypes.c_uint32),
    ('max', ctypes.c_uint32 * 16),
    ('min', ctypes.c_uint32 * 16),
     ]

class struct_smu_11_0_powerplay_table(ctypes.Structure):
    _pack_ = True # source:True
    _fields_ = [
    ('header', struct_atom_common_table_header),
    ('table_revision', ctypes.c_ubyte),
    ('table_size', ctypes.c_uint16),
    ('golden_pp_id', ctypes.c_uint32),
    ('golden_revision', ctypes.c_uint32),
    ('format_id', ctypes.c_uint16),
    ('platform_caps', ctypes.c_uint32),
    ('thermal_controller_type', ctypes.c_ubyte),
    ('small_power_limit1', ctypes.c_uint16),
    ('small_power_limit2', ctypes.c_uint16),
    ('boost_power_limit', ctypes.c_uint16),
    ('od_turbo_power_limit', ctypes.c_uint16),
    ('od_power_save_power_limit', ctypes.c_uint16),
    ('software_shutdown_temp', ctypes.c_uint16),
    ('reserve', ctypes.c_uint16 * 6),
    ('power_saving_clock', struct_smu_11_0_power_saving_clock_table),
    ('overdrive_table', struct_smu_11_0_overdrive_table),
    ('smc_pptable', struct_c__SA_PPTable_t),
     ]

__all__ = \
    ['SMU_11_0_MAX_ODFEATURE', 'SMU_11_0_MAX_ODSETTING',
    'SMU_11_0_MAX_PPCLOCK', 'SMU_11_0_PPTABLE_H',
    'SMU_11_0_PP_OVERDRIVE_VERSION', 'SMU_11_0_PP_PLATFORM_CAP_BACO',
    'SMU_11_0_PP_PLATFORM_CAP_HARDWAREDC',
    'SMU_11_0_PP_PLATFORM_CAP_MACO',
    'SMU_11_0_PP_PLATFORM_CAP_POWERPLAY',
    'SMU_11_0_PP_PLATFORM_CAP_SBIOSPOWERSOURCE',
    'SMU_11_0_PP_PLATFORM_CAP_SHADOWPSTATE',
    'SMU_11_0_PP_POWERSAVINGCLOCK_VERSION',
    'SMU_11_0_PP_THERMALCONTROLLER_NONE',
    'SMU_11_0_TABLE_FORMAT_REVISION',
    'struct_atom_common_table_header', 'struct_c__SA_DpmDescriptor_t',
    'struct_c__SA_DroopInt_t', 'struct_c__SA_I2cControllerConfig_t',
    'struct_c__SA_LinearInt_t', 'struct_c__SA_PPTable_t',
    'struct_c__SA_QuadraticInt_t', 'struct_smu_11_0_overdrive_table',
    'struct_smu_11_0_power_saving_clock_table',
    'struct_smu_11_0_powerplay_table']



# -*- coding: utf-8 -*-
#
# TARGET arch is: ['--include', 'stdint.h', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '--include', 'linux/drivers/gpu/drm/amd/include/atom-types.h', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '--include', 'linux/drivers/gpu/drm/amd/include/atomfirmware.h', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '--include', 'linux/drivers/gpu/drm/amd/pm/inc/smu11_driver_if_sienna_cichlid.h', '']
# WORD_SIZE is: 8
# POINTER_SIZE is: 8
# LONGDOUBLE_SIZE is: 16
#
import ctypes




class struct_atom_common_table_header(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('structuresize', ctypes.c_uint16),
    ('format_revision', ctypes.c_ubyte),
    ('content_revision', ctypes.c_ubyte),
     ]

class struct_c__SA_I2cControllerConfig_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('Enabled', ctypes.c_ubyte),
    ('Speed', ctypes.c_ubyte),
    ('SlaveAddress', ctypes.c_ubyte),
    ('ControllerPort', ctypes.c_ubyte),
    ('ControllerName', ctypes.c_ubyte),
    ('ThermalThrotter', ctypes.c_ubyte),
    ('I2cProtocol', ctypes.c_ubyte),
    ('PaddingConfig', ctypes.c_ubyte),
     ]

class struct_c__SA_QuadraticInt_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('a', ctypes.c_uint32),
    ('b', ctypes.c_uint32),
    ('c', ctypes.c_uint32),
     ]

class struct_c__SA_LinearInt_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('m', ctypes.c_uint32),
    ('b', ctypes.c_uint32),
     ]

class struct_c__SA_DroopInt_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('a', ctypes.c_uint32),
    ('b', ctypes.c_uint32),
    ('c', ctypes.c_uint32),
     ]

class struct_c__SA_PiecewiseLinearDroopInt_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('Fset', ctypes.c_uint32 * 5),
    ('Vdroop', ctypes.c_uint32 * 5),
     ]

class struct_c__SA_DpmDescriptor_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('VoltageMode', ctypes.c_ubyte),
    ('SnapToDiscrete', ctypes.c_ubyte),
    ('NumDiscreteLevels', ctypes.c_ubyte),
    ('Padding', ctypes.c_ubyte),
    ('ConversionToAvfsClk', struct_c__SA_LinearInt_t),
    ('SsCurve', struct_c__SA_QuadraticInt_t),
    ('SsFmin', ctypes.c_uint16),
    ('Padding16', ctypes.c_uint16),
     ]

class struct_c__SA_UclkDpmChangeRange_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('Fmin', ctypes.c_uint16),
    ('Fmax', ctypes.c_uint16),
     ]

class struct_c__SA_PPTable_t(ctypes.Structure):
    _pack_ = True # source:False
    _fields_ = [
    ('Version', ctypes.c_uint32),
    ('FeaturesToRun', ctypes.c_uint32 * 2),
    ('SocketPowerLimitAc', ctypes.c_uint16 * 4),
    ('SocketPowerLimitAcTau', ctypes.c_uint16 * 4),
    ('SocketPowerLimitDc', ctypes.c_uint16 * 4),
    ('SocketPowerLimitDcTau', ctypes.c_uint16 * 4),
    ('TdcLimit', ctypes.c_uint16 * 2),
    ('TdcLimitTau', ctypes.c_uint16 * 2),
    ('TemperatureLimit', ctypes.c_uint16 * 10),
    ('FitLimit', ctypes.c_uint32),
    ('TotalPowerConfig', ctypes.c_ubyte),
    ('TotalPowerPadding', ctypes.c_ubyte * 3),
    ('ApccPlusResidencyLimit', ctypes.c_uint32),
    ('SmnclkDpmFreq', ctypes.c_uint16 * 2),
    ('SmnclkDpmVoltage', ctypes.c_uint16 * 2),
    ('PaddingAPCC', ctypes.c_uint32 * 4),
    ('ThrottlerControlMask', ctypes.c_uint32),
    ('FwDStateMask', ctypes.c_uint32),
    ('UlvVoltageOffsetSoc', ctypes.c_uint16),
    ('UlvVoltageOffsetGfx', ctypes.c_uint16),
    ('MinVoltageUlvGfx', ctypes.c_uint16),
    ('MinVoltageUlvSoc', ctypes.c_uint16),
    ('SocLIVmin', ctypes.c_uint16),
    ('PaddingLIVmin', ctypes.c_uint16),
    ('GceaLinkMgrIdleThreshold', ctypes.c_ubyte),
    ('paddingRlcUlvParams', ctypes.c_ubyte * 3),
    ('MinVoltageGfx', ctypes.c_uint16),
    ('MinVoltageSoc', ctypes.c_uint16),
    ('MaxVoltageGfx', ctypes.c_uint16),
    ('MaxVoltageSoc', ctypes.c_uint16),
    ('LoadLineResistanceGfx', ctypes.c_uint16),
    ('LoadLineResistanceSoc', ctypes.c_uint16),
    ('VDDGFX_TVmin', ctypes.c_uint16),
    ('VDDSOC_TVmin', ctypes.c_uint16),
    ('VDDGFX_Vmin_HiTemp', ctypes.c_uint16),
    ('VDDGFX_Vmin_LoTemp', ctypes.c_uint16),
    ('VDDSOC_Vmin_HiTemp', ctypes.c_uint16),
    ('VDDSOC_Vmin_LoTemp', ctypes.c_uint16),
    ('VDDGFX_TVminHystersis', ctypes.c_uint16),
    ('VDDSOC_TVminHystersis', ctypes.c_uint16),
    ('DpmDescriptor', struct_c__SA_DpmDescriptor_t * 13),
    ('FreqTableGfx', ctypes.c_uint16 * 16),
    ('FreqTableVclk', ctypes.c_uint16 * 8),
    ('FreqTableDclk', ctypes.c_uint16 * 8),
    ('FreqTableSocclk', ctypes.c_uint16 * 8),
    ('FreqTableUclk', ctypes.c_uint16 * 4),
    ('FreqTableDcefclk', ctypes.c_uint16 * 8),
    ('FreqTableDispclk', ctypes.c_uint16 * 8),
    ('FreqTablePixclk', ctypes.c_uint16 * 8),
    ('FreqTablePhyclk', ctypes.c_uint16 * 8),
    ('FreqTableDtbclk', ctypes.c_uint16 * 8),
    ('FreqTableFclk', ctypes.c_uint16 * 8),
    ('Paddingclks', ctypes.c_uint32 * 16),
    ('DcModeMaxFreq', ctypes.c_uint32 * 13),
    ('FreqTableUclkDiv', ctypes.c_ubyte * 4),
    ('FclkBoostFreq', ctypes.c_uint16),
    ('FclkParamPadding', ctypes.c_uint16),
    ('Mp0clkFreq', ctypes.c_uint16 * 2),
    ('Mp0DpmVoltage', ctypes.c_uint16 * 2),
    ('MemVddciVoltage', ctypes.c_uint16 * 4),
    ('MemMvddVoltage', ctypes.c_uint16 * 4),
    ('GfxclkFgfxoffEntry', ctypes.c_uint16),
    ('GfxclkFinit', ctypes.c_uint16),
    ('GfxclkFidle', ctypes.c_uint16),
    ('GfxclkSource', ctypes.c_ubyte),
    ('GfxclkPadding', ctypes.c_ubyte),
    ('GfxGpoSubFeatureMask', ctypes.c_ubyte),
    ('GfxGpoEnabledWorkPolicyMask', ctypes.c_ubyte),
    ('GfxGpoDisabledWorkPolicyMask', ctypes.c_ubyte),
    ('GfxGpoPadding', ctypes.c_ubyte * 1),
    ('GfxGpoVotingAllow', ctypes.c_uint32),
    ('GfxGpoPadding32', ctypes.c_uint32 * 4),
    ('GfxDcsFopt', ctypes.c_uint16),
    ('GfxDcsFclkFopt', ctypes.c_uint16),
    ('GfxDcsUclkFopt', ctypes.c_uint16),
    ('DcsGfxOffVoltage', ctypes.c_uint16),
    ('DcsMinGfxOffTime', ctypes.c_uint16),
    ('DcsMaxGfxOffTime', ctypes.c_uint16),
    ('DcsMinCreditAccum', ctypes.c_uint32),
    ('DcsExitHysteresis', ctypes.c_uint16),
    ('DcsTimeout', ctypes.c_uint16),
    ('DcsParamPadding', ctypes.c_uint32 * 5),
    ('FlopsPerByteTable', ctypes.c_uint16 * 16),
    ('LowestUclkReservedForUlv', ctypes.c_ubyte),
    ('PaddingMem', ctypes.c_ubyte * 3),
    ('UclkDpmPstates', ctypes.c_ubyte * 4),
    ('UclkDpmSrcFreqRange', struct_c__SA_UclkDpmChangeRange_t),
    ('UclkDpmTargFreqRange', struct_c__SA_UclkDpmChangeRange_t),
    ('UclkDpmMidstepFreq', ctypes.c_uint16),
    ('UclkMidstepPadding', ctypes.c_uint16),
    ('PcieGenSpeed', ctypes.c_ubyte * 2),
    ('PcieLaneCount', ctypes.c_ubyte * 2),
    ('LclkFreq', ctypes.c_uint16 * 2),
    ('FanStopTemp', ctypes.c_uint16),
    ('FanStartTemp', ctypes.c_uint16),
    ('FanGain', ctypes.c_uint16 * 10),
    ('FanPwmMin', ctypes.c_uint16),
    ('FanAcousticLimitRpm', ctypes.c_uint16),
    ('FanThrottlingRpm', ctypes.c_uint16),
    ('FanMaximumRpm', ctypes.c_uint16),
    ('MGpuFanBoostLimitRpm', ctypes.c_uint16),
    ('FanTargetTemperature', ctypes.c_uint16),
    ('FanTargetGfxclk', ctypes.c_uint16),
    ('FanPadding16', ctypes.c_uint16),
    ('FanTempInputSelect', ctypes.c_ubyte),
    ('FanPadding', ctypes.c_ubyte),
    ('FanZeroRpmEnable', ctypes.c_ubyte),
    ('FanTachEdgePerRev', ctypes.c_ubyte),
    ('FuzzyFan_ErrorSetDelta', ctypes.c_int16),
    ('FuzzyFan_ErrorRateSetDelta', ctypes.c_int16),
    ('FuzzyFan_PwmSetDelta', ctypes.c_int16),
    ('FuzzyFan_Reserved', ctypes.c_uint16),
    ('OverrideAvfsGb', ctypes.c_ubyte * 2),
    ('dBtcGbGfxDfllModelSelect', ctypes.c_ubyte),
    ('Padding8_Avfs', ctypes.c_ubyte),
    ('qAvfsGb', struct_c__SA_QuadraticInt_t * 2),
    ('dBtcGbGfxPll', struct_c__SA_DroopInt_t),
    ('dBtcGbGfxDfll', struct_c__SA_DroopInt_t),
    ('dBtcGbSoc', struct_c__SA_DroopInt_t),
    ('qAgingGb', struct_c__SA_LinearInt_t * 2),
    ('PiecewiseLinearDroopIntGfxDfll', struct_c__SA_PiecewiseLinearDroopInt_t),
    ('qStaticVoltageOffset', struct_c__SA_QuadraticInt_t * 2),
    ('DcTol', ctypes.c_uint16 * 2),
    ('DcBtcEnabled', ctypes.c_ubyte * 2),
    ('Padding8_GfxBtc', ctypes.c_ubyte * 2),
    ('DcBtcMin', ctypes.c_uint16 * 2),
    ('DcBtcMax', ctypes.c_uint16 * 2),
    ('DcBtcGb', ctypes.c_uint16 * 2),
    ('XgmiDpmPstates', ctypes.c_ubyte * 2),
    ('XgmiDpmSpare', ctypes.c_ubyte * 2),
    ('DebugOverrides', ctypes.c_uint32),
    ('ReservedEquation0', struct_c__SA_QuadraticInt_t),
    ('ReservedEquation1', struct_c__SA_QuadraticInt_t),
    ('ReservedEquation2', struct_c__SA_QuadraticInt_t),
    ('ReservedEquation3', struct_c__SA_QuadraticInt_t),
    ('CustomerVariant', ctypes.c_ubyte),
    ('VcBtcEnabled', ctypes.c_ubyte),
    ('VcBtcVminT0', ctypes.c_uint16),
    ('VcBtcFixedVminAgingOffset', ctypes.c_uint16),
    ('VcBtcVmin2PsmDegrationGb', ctypes.c_uint16),
    ('VcBtcPsmA', ctypes.c_uint32),
    ('VcBtcPsmB', ctypes.c_uint32),
    ('VcBtcVminA', ctypes.c_uint32),
    ('VcBtcVminB', ctypes.c_uint32),
    ('SkuReserved', ctypes.c_uint32 * 9),
    ('GamingClk', ctypes.c_uint32 * 6),
    ('I2cControllers', struct_c__SA_I2cControllerConfig_t * 16),
    ('GpioScl', ctypes.c_ubyte),
    ('GpioSda', ctypes.c_ubyte),
    ('FchUsbPdSlaveAddr', ctypes.c_ubyte),
    ('I2cSpare', ctypes.c_ubyte * 1),
    ('VddGfxVrMapping', ctypes.c_ubyte),
    ('VddSocVrMapping', ctypes.c_ubyte),
    ('VddMem0VrMapping', ctypes.c_ubyte),
    ('VddMem1VrMapping', ctypes.c_ubyte),
    ('GfxUlvPhaseSheddingMask', ctypes.c_ubyte),
    ('SocUlvPhaseSheddingMask', ctypes.c_ubyte),
    ('VddciUlvPhaseSheddingMask', ctypes.c_ubyte),
    ('MvddUlvPhaseSheddingMask', ctypes.c_ubyte),
    ('GfxMaxCurrent', ctypes.c_uint16),
    ('GfxOffset', ctypes.c_byte),
    ('Padding_TelemetryGfx', ctypes.c_ubyte),
    ('SocMaxCurrent', ctypes.c_uint16),
    ('SocOffset', ctypes.c_byte),
    ('Padding_TelemetrySoc', ctypes.c_ubyte),
    ('Mem0MaxCurrent', ctypes.c_uint16),
    ('Mem0Offset', ctypes.c_byte),
    ('Padding_TelemetryMem0', ctypes.c_ubyte),
    ('Mem1MaxCurrent', ctypes.c_uint16),
    ('Mem1Offset', ctypes.c_byte),
    ('Padding_TelemetryMem1', ctypes.c_ubyte),
    ('MvddRatio', ctypes.c_uint32),
    ('AcDcGpio', ctypes.c_ubyte),
    ('AcDcPolarity', ctypes.c_ubyte),
    ('VR0HotGpio', ctypes.c_ubyte),
    ('VR0HotPolarity', ctypes.c_ubyte),
    ('VR1HotGpio', ctypes.c_ubyte),
    ('VR1HotPolarity', ctypes.c_ubyte),
    ('GthrGpio', ctypes.c_ubyte),
    ('GthrPolarity', ctypes.c_ubyte),
    ('LedPin0', ctypes.c_ubyte),
    ('LedPin1', ctypes.c_ubyte),
    ('LedPin2', ctypes.c_ubyte),
    ('LedEnableMask', ctypes.c_ubyte),
    ('LedPcie', ctypes.c_ubyte),
    ('LedError', ctypes.c_ubyte),
    ('LedSpare1', ctypes.c_ubyte * 2),
    ('PllGfxclkSpreadEnabled', ctypes.c_ubyte),
    ('PllGfxclkSpreadPercent', ctypes.c_ubyte),
    ('PllGfxclkSpreadFreq', ctypes.c_uint16),
    ('DfllGfxclkSpreadEnabled', ctypes.c_ubyte),
    ('DfllGfxclkSpreadPercent', ctypes.c_ubyte),
    ('DfllGfxclkSpreadFreq', ctypes.c_uint16),
    ('UclkSpreadPadding', ctypes.c_uint16),
    ('UclkSpreadFreq', ctypes.c_uint16),
    ('FclkSpreadEnabled', ctypes.c_ubyte),
    ('FclkSpreadPercent', ctypes.c_ubyte),
    ('FclkSpreadFreq', ctypes.c_uint16),
    ('MemoryChannelEnabled', ctypes.c_uint32),
    ('DramBitWidth', ctypes.c_ubyte),
    ('PaddingMem1', ctypes.c_ubyte * 3),
    ('TotalBoardPower', ctypes.c_uint16),
    ('BoardPowerPadding', ctypes.c_uint16),
    ('XgmiLinkSpeed', ctypes.c_ubyte * 4),
    ('XgmiLinkWidth', ctypes.c_ubyte * 4),
    ('XgmiFclkFreq', ctypes.c_uint16 * 4),
    ('XgmiSocVoltage', ctypes.c_uint16 * 4),
    ('HsrEnabled', ctypes.c_ubyte),
    ('VddqOffEnabled', ctypes.c_ubyte),
    ('PaddingUmcFlags', ctypes.c_ubyte * 2),
    ('UclkSpreadPercent', ctypes.c_ubyte * 16),
    ('BoardReserved', ctypes.c_uint32 * 11),
    ('MmHubPadding', ctypes.c_uint32 * 8),
     ]

SMU_11_0_7_PPTABLE_H = True # macro
SMU_11_0_7_TABLE_FORMAT_REVISION = 15 # macro
SMU_11_0_7_PP_PLATFORM_CAP_POWERPLAY = 0x1 # macro
SMU_11_0_7_PP_PLATFORM_CAP_SBIOSPOWERSOURCE = 0x2 # macro
SMU_11_0_7_PP_PLATFORM_CAP_HARDWAREDC = 0x4 # macro
SMU_11_0_7_PP_PLATFORM_CAP_BACO = 0x8 # macro
SMU_11_0_7_PP_PLATFORM_CAP_MACO = 0x10 # macro
SMU_11_0_7_PP_PLATFORM_CAP_SHADOWPSTATE = 0x20 # macro
SMU_11_0_7_PP_THERMALCONTROLLER_NONE = 0 # macro
SMU_11_0_7_PP_THERMALCONTROLLER_SIENNA_CICHLID = 28 # macro
SMU_11_0_7_PP_OVERDRIVE_VERSION = 0x81 # macro
SMU_11_0_7_PP_POWERSAVINGCLOCK_VERSION = 0x01 # macro
SMU_11_0_7_MAX_ODFEATURE = 32 # macro
SMU_11_0_7_MAX_ODSETTING = 64 # macro
SMU_11_0_7_MAX_PMSETTING = 32 # macro
class struct_smu_11_0_7_overdrive_table(ctypes.Structure):
    _pack_ = True # source:True
    _fields_ = [
    ('revision', ctypes.c_ubyte),
    ('reserve', ctypes.c_ubyte * 3),
    ('feature_count', ctypes.c_uint32),
    ('setting_count', ctypes.c_uint32),
    ('cap', ctypes.c_ubyte * 32),
    ('max', ctypes.c_uint32 * 64),
    ('min', ctypes.c_uint32 * 64),
    ('pm_setting', ctypes.c_int16 * 32),
     ]

SMU_11_0_7_MAX_PPCLOCK = 16 # macro
class struct_smu_11_0_7_power_saving_clock_table(ctypes.Structure):
    _pack_ = True # source:True
    _fields_ = [
    ('revision', ctypes.c_ubyte),
    ('reserve', ctypes.c_ubyte * 3),
    ('count', ctypes.c_uint32),
    ('max', ctypes.c_uint32 * 16),
    ('min', ctypes.c_uint32 * 16),
     ]

class struct_smu_11_0_7_powerplay_table(ctypes.Structure):
    _pack_ = True # source:True
    _fields_ = [
    ('header', struct_atom_common_table_header),
    ('table_revision', ctypes.c_ubyte),
    ('table_size', ctypes.c_uint16),
    ('golden_pp_id', ctypes.c_uint32),
    ('golden_revision', ctypes.c_uint32),
    ('format_id', ctypes.c_uint16),
    ('platform_caps', ctypes.c_uint32),
    ('thermal_controller_type', ctypes.c_ubyte),
    ('small_power_limit1', ctypes.c_uint16),
    ('small_power_limit2', ctypes.c_uint16),
    ('boost_power_limit', ctypes.c_uint16),
    ('software_shutdown_temp', ctypes.c_uint16),
    ('reserve', ctypes.c_uint16 * 8),
    ('power_saving_clock', struct_smu_11_0_7_power_saving_clock_table),
    ('overdrive_table', struct_smu_11_0_7_overdrive_table),
    ('smc_pptable', struct_c__SA_PPTable_t),
     ]

__all__ = \
    ['SMU_11_0_7_MAX_ODFEATURE', 'SMU_11_0_7_MAX_ODSETTING',
    'SMU_11_0_7_MAX_PMSETTING', 'SMU_11_0_7_MAX_PPCLOCK',
    'SMU_11_0_7_PPTABLE_H', 'SMU_11_0_7_PP_OVERDRIVE_VERSION',
    'SMU_11_0_7_PP_PLATFORM_CAP_BACO',
    'SMU_11_0_7_PP_PLATFORM_CAP_HARDWAREDC',
    'SMU_11_0_7_PP_PLATFORM_CAP_MACO',
    'SMU_11_0_7_PP_PLATFORM_CAP_POWERPLAY',
    'SMU_11_0_7_PP_PLATFORM_CAP_SBIOSPOWERSOURCE',
    'SMU_11_0_7_PP_PLATFORM_CAP_SHADOWPSTATE',
    'SMU_11_0_7_PP_POWERSAVINGCLOCK_VERSION',
    'SMU_11_0_7_PP_THERMALCONTROLLER_NONE',
    'SMU_11_0_7_PP_THERMALCONTROLLER_SIENNA_CICHLID',
    'SMU_11_0_7_TABLE_FORMAT_REVISION',
    'struct_atom_common_table_header', 'struct_c__SA_DpmDescriptor_t',
    'struct_c__SA_DroopInt_t', 'struct_c__SA_I2cControllerConfig_t',
    'struct_c__SA_LinearInt_t', 'struct_c__SA_PPTable_t',
    'struct_c__SA_PiecewiseLinearDroopInt_t',
    'struct_c__SA_QuadraticInt_t',
    'struct_c__SA_UclkDpmChangeRange_t',
    'struct_smu_11_0_7_overdrive_table',
    'struct_smu_11_0_7_power_saving_clock_table',
    'struct_smu_11_0_7_powerplay_table']



# -*- coding: utf-8 -*-
#
# TARGET arch is: ['--include', 'stdint.h']
# WORD_SIZE is: 8
# POINTER_SIZE is: 8
# LONGDOUBLE_SIZE is: 16
#
import ctypes




ATOM_H = True # macro
ATOM_BIOS_MAGIC = 0xAA55 # macro
ATOM_ATI_MAGIC_PTR = 0x30 # macro
ATOM_ATI_MAGIC = " 761295520" # macro
ATOM_ROM_TABLE_PTR = 0x48 # macro
ATOM_ROM_PART_NUMBER_PTR = 0x6E # macro
ATOM_ROM_MAGIC = "ATOM" # macro
ATOM_ROM_MAGIC_PTR = 4 # macro
ATOM_ROM_MSG_PTR = 0x10 # macro
ATOM_ROM_CMD_PTR = 0x1E # macro
ATOM_ROM_DATA_PTR = 0x20 # macro
ATOM_CMD_INIT = 0 # macro
ATOM_CMD_SETSCLK = 0x0A # macro
ATOM_CMD_SETMCLK = 0x0B # macro
ATOM_CMD_SETPCLK = 0x0C # macro
ATOM_CMD_SPDFANCNTL = 0x39 # macro
ATOM_DATA_FWI_PTR = 0xC # macro
ATOM_DATA_IIO_PTR = 0x32 # macro
ATOM_FWI_DEFSCLK_PTR = 8 # macro
ATOM_FWI_DEFMCLK_PTR = 0xC # macro
ATOM_FWI_MAXSCLK_PTR = 0x24 # macro
ATOM_FWI_MAXMCLK_PTR = 0x28 # macro
ATOM_CT_SIZE_PTR = 0 # macro
ATOM_CT_WS_PTR = 4 # macro
ATOM_CT_PS_PTR = 5 # macro
ATOM_CT_PS_MASK = 0x7F # macro
ATOM_CT_CODE_PTR = 6 # macro
ATOM_OP_CNT = 127 # macro
ATOM_OP_EOT = 91 # macro
ATOM_CASE_MAGIC = 0x63 # macro
ATOM_CASE_END = 0x5A5A # macro
ATOM_ARG_REG = 0 # macro
ATOM_ARG_PS = 1 # macro
ATOM_ARG_WS = 2 # macro
ATOM_ARG_FB = 3 # macro
ATOM_ARG_ID = 4 # macro
ATOM_ARG_IMM = 5 # macro
ATOM_ARG_PLL = 6 # macro
ATOM_ARG_MC = 7 # macro
ATOM_SRC_DWORD = 0 # macro
ATOM_SRC_WORD0 = 1 # macro
ATOM_SRC_WORD8 = 2 # macro
ATOM_SRC_WORD16 = 3 # macro
ATOM_SRC_BYTE0 = 4 # macro
ATOM_SRC_BYTE8 = 5 # macro
ATOM_SRC_BYTE16 = 6 # macro
ATOM_SRC_BYTE24 = 7 # macro
ATOM_WS_QUOTIENT = 0x40 # macro
ATOM_WS_REMAINDER = 0x41 # macro
ATOM_WS_DATAPTR = 0x42 # macro
ATOM_WS_SHIFT = 0x43 # macro
ATOM_WS_OR_MASK = 0x44 # macro
ATOM_WS_AND_MASK = 0x45 # macro
ATOM_WS_FB_WINDOW = 0x46 # macro
ATOM_WS_ATTRIBUTES = 0x47 # macro
ATOM_WS_REGPTR = 0x48 # macro
ATOM_IIO_NOP = 0 # macro
ATOM_IIO_START = 1 # macro
ATOM_IIO_READ = 2 # macro
ATOM_IIO_WRITE = 3 # macro
ATOM_IIO_CLEAR = 4 # macro
ATOM_IIO_SET = 5 # macro
ATOM_IIO_MOVE_INDEX = 6 # macro
ATOM_IIO_MOVE_ATTR = 7 # macro
ATOM_IIO_MOVE_DATA = 8 # macro
ATOM_IIO_END = 9 # macro
ATOM_IO_MM = 0 # macro
ATOM_IO_PCI = 1 # macro
ATOM_IO_SYSIO = 2 # macro
ATOM_IO_IIO = 0x80 # macro
__all__ = \
    ['ATOM_ARG_FB', 'ATOM_ARG_ID', 'ATOM_ARG_IMM', 'ATOM_ARG_MC',
    'ATOM_ARG_PLL', 'ATOM_ARG_PS', 'ATOM_ARG_REG', 'ATOM_ARG_WS',
    'ATOM_ATI_MAGIC', 'ATOM_ATI_MAGIC_PTR', 'ATOM_BIOS_MAGIC',
    'ATOM_CASE_END', 'ATOM_CASE_MAGIC', 'ATOM_CMD_INIT',
    'ATOM_CMD_SETMCLK', 'ATOM_CMD_SETPCLK', 'ATOM_CMD_SETSCLK',
    'ATOM_CMD_SPDFANCNTL', 'ATOM_CT_CODE_PTR', 'ATOM_CT_PS_MASK',
    'ATOM_CT_PS_PTR', 'ATOM_CT_SIZE_PTR', 'ATOM_CT_WS_PTR',
    'ATOM_DATA_FWI_PTR', 'ATOM_DATA_IIO_PTR', 'ATOM_FWI_DEFMCLK_PTR',
    'ATOM_FWI_DEFSCLK_PTR', 'ATOM_FWI_MAXMCLK_PTR',
    'ATOM_FWI_MAXSCLK_PTR', 'ATOM_H', 'ATOM_IIO_CLEAR',
    'ATOM_IIO_END', 'ATOM_IIO_MOVE_ATTR', 'ATOM_IIO_MOVE_DATA',
    'ATOM_IIO_MOVE_INDEX', 'ATOM_IIO_NOP', 'ATOM_IIO_READ',
    'ATOM_IIO_SET', 'ATOM_IIO_START', 'ATOM_IIO_WRITE', 'ATOM_IO_IIO',
    'ATOM_IO_MM', 'ATOM_IO_PCI', 'ATOM_IO_SYSIO', 'ATOM_OP_CNT',
    'ATOM_OP_EOT', 'ATOM_ROM_CMD_PTR', 'ATOM_ROM_DATA_PTR',
    'ATOM_ROM_MAGIC', 'ATOM_ROM_MAGIC_PTR', 'ATOM_ROM_MSG_PTR',
    'ATOM_ROM_PART_NUMBER_PTR', 'ATOM_ROM_TABLE_PTR',
    'ATOM_SRC_BYTE0', 'ATOM_SRC_BYTE16', 'ATOM_SRC_BYTE24',
    'ATOM_SRC_BYTE8', 'ATOM_SRC_DWORD', 'ATOM_SRC_WORD0',
    'ATOM_SRC_WORD16', 'ATOM_SRC_WORD8', 'ATOM_WS_AND_MASK',
    'ATOM_WS_ATTRIBUTES', 'ATOM_WS_DATAPTR', 'ATOM_WS_FB_WINDOW',
    'ATOM_WS_OR_MASK', 'ATOM_WS_QUOTIENT', 'ATOM_WS_REGPTR',
    'ATOM_WS_REMAINDER', 'ATOM_WS_SHIFT']



import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='upp',
    version='0.0.8',
    author='Samir Ibradžić',
    description='Uplift Power Play',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/sibradzic/upp',
    package_dir={'': 'src'},
    packages=['upp', 'upp/atom_gen'],
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6, <4',
    install_requires=[
        'click',
        'setuptools'
    ],
    entry_points={
        'console_scripts': [
            'upp=upp.upp:main',
        ],
    },
)
